@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.6 
+/* GrandPerspective, Version 3.6.1 
  *   A utility for macOS that graphically shows disk usage. 
  * Copyright (C) 2005-2025, Erwin Bonsma 
  * 
@@ -213,7 +213,7 @@ NSString  *AfterClosingLastViewDoNothing = @"do nothing";
 
 - (void) viewWillOpen:(NSNotification *)notification;
 - (void) viewWillClose:(NSNotification *)notification;
-- (void) viewProducingTaskStarted:(NSNotification *)notification;
+- (void) viewProducingTaskScheduled:(NSNotification *)notification;
 - (void) viewProducingTaskCompleted:(NSNotification *)notification;
 
 - (void) checkShowWelcomeWindow:(BOOL)allowAutoQuit;
@@ -358,8 +358,8 @@ static dispatch_once_t  singletonOnceToken;
     NSArray*  viewProducingTaskManagers = @[scanTaskManager, filterTaskManager, xmlReadTaskManager];
     for (NSObject*  taskManager in [viewProducingTaskManagers objectEnumerator]) {
       [nc addObserver: self
-             selector: @selector(viewProducingTaskStarted:)
-                 name: TaskStartedEvent
+             selector: @selector(viewProducingTaskScheduled:)
+                 name: TaskScheduledEvent
                object: taskManager];
       [nc addObserver: self
              selector: @selector(viewProducingTaskCompleted:)
@@ -639,12 +639,12 @@ static dispatch_once_t  singletonOnceToken;
 
   NSString  *rescanBehaviour = [NSUserDefaults.standardUserDefaults
                                 stringForKey: RescanBehaviourKey];
+  TreeContext  *oldContext = oldControl.treeContext;
+  [self rescanItem: oldContext.scanTree deriveFrom: oldControl];
+
   if ([rescanBehaviour isEqualToString: RescanClosesOldWindow]) {
     [oldControl.window close];
   }
-  
-  TreeContext  *oldContext = oldControl.treeContext;
-  [self rescanItem: oldContext.scanTree deriveFrom: oldControl];
 }
 
 - (IBAction) rescanVisible:(id)sender {
@@ -1268,7 +1268,7 @@ static dispatch_once_t  singletonOnceToken;
   [self checkShowWelcomeWindow: YES];
 }
 
-- (void) viewProducingTaskStarted:(NSNotification *)notification {
+- (void) viewProducingTaskScheduled:(NSNotification *)notification {
   viewTaskCount++;
   NSLog(@"viewCount = %d, viewTaskCount = %d", viewCount, viewTaskCount);
 }
