@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.6 
+/* GrandPerspective, Version 3.6.1 
  *   A utility for macOS that graphically shows disk usage. 
  * Copyright (C) 2005-2025, Erwin Bonsma 
  * 
@@ -48,6 +48,7 @@ extern NSString  *DelayBeforeWelcomeWindowAfterStartupKey;
 extern NSString  *KeyboardNavigationDeltaKey;
 extern NSString  *PackageCheckBehaviorKey;
 extern NSString  *DefaultDisplayFocusKey;
+extern NSString  *SuppressFdaWarningSheetKey;
 
 extern NSString  *UnlimitedDisplayFocusValue;
 
