@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.6 
+/* GrandPerspective, Version 3.6.1 
  *   A utility for macOS that graphically shows disk usage. 
  * Copyright (C) 2005-2025, Erwin Bonsma 
  * 
@@ -51,6 +51,8 @@ NSString  *ShowPackageContentsByDefaultKey_Deprecated = @"showPackageContentsByD
 // Deprecated since 3.1.0
 NSString  *DefaultFilterKey_Deprecated = @"defaultFilter";
 
+// Can be set from the FDA warning sheet
+NSString  *SuppressFdaWarningSheetKey = @"suppressFdaWarningSheet";
 
 /* Note: The preferences below cannot currently be changed from the preferences panel; they are set
  * by the application defaults and can be changed by manually editing the user preferences file.
