@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.6 
+/* GrandPerspective, Version 3.6.1 
  *   A utility for macOS that graphically shows disk usage. 
  * Copyright (C) 2005-2025, Erwin Bonsma 
  * 
@@ -22,16 +22,32 @@
 #import "NSURL.h"
 #import "RecentDocumentTableCellView.h"
 #import "LocalizableStrings.h"
+#import "ControlConstants.h"
+#import "PreferencesPanelControl.h"
 
 NSString*  TaglineTable = @"Taglines";
 NSString*  NumTaglines = @"num-taglines";
 NSString*  TaglineFormat = @"tagline-%d";
 
+NSString*  fdaPreferencesUrl =
+  @"x-apple.systempreferences:com.apple.preference.security?Privacy_AllFiles";
+
+NSString*  checkFdaPermissionsPath = @"~/Library/Containers/com.apple.stocks";
+
 @interface StartWindowControl (PrivateMethods)
 
 - (void) setTagLineField;
 - (void) startScan:(NSInteger)selectedRow sender:(id)sender;
 
+@property (nonatomic, readonly) NSString *appVersionString;
+
+- (BOOL) hasFdaPermissions;
+- (BOOL) suppressFdaSheetEnabled;
+- (BOOL) shouldShowFdaWarningSheet;
+- (void) showFdaWarningSheet;
+- (void) handleSuppressFdaWarningButton:(id)sender;
+- (void) handleEditFdaPreferences;
+
 @end // @interface StartWindowControl (PrivateMethods)
 
 @implementation StartWindowControl
@@ -181,6 +197,10 @@ NSString*  TaglineFormat = @"tagline-%d";
     NSDocumentController.sharedDocumentController.recentDocumentURLs.count > 0;
 
   [super showWindow: sender];
+
+  if ([self shouldShowFdaWarningSheet]) {
+    [self showFdaWarningSheet];
+  }
 }
 
 // Invoked because the controller is the delegate for the window.
@@ -225,4 +245,98 @@ NSString*  TaglineFormat = @"tagline-%d";
   }
 }
 
+- (NSString *)appVersionString {
+  return [NSBundle.mainBundle objectForInfoDictionaryKey: @"CFBundleShortVersionString"];
+}
+
+- (BOOL) hasFdaPermissions {
+  NSString *path = checkFdaPermissionsPath.stringByExpandingTildeInPath;
+  NSString *tildeReplacement = [path substringToIndex:
+                                path.length - checkFdaPermissionsPath.length + 1];
+
+  NSRange range = [tildeReplacement rangeOfString: @"/Library/Containers"];
+  if (range.location != NSNotFound) {
+    // Path is sand-boxed. Replace sandbox home path by actual user home.
+
+    NSString *userHome = [tildeReplacement substringToIndex: range.location];
+    path = [userHome stringByAppendingPathComponent:
+            [checkFdaPermissionsPath substringFromIndex: 2]];
+  }
+
+  NSError *error = nil;
+  [NSFileManager.defaultManager contentsOfDirectoryAtPath: path error: &error];
+
+  if (error) {
+    NSLog(@"FDA permission check using %@ failed, error: %@", path, error);
+    return NO;
+  }
+
+  NSLog(@"FDA permission check using %@ succeeded", path);
+  return YES;
+}
+
+- (BOOL) suppressFdaSheetEnabled {
+  NSUserDefaults  *userDefaults = NSUserDefaults.standardUserDefaults;
+  NSString  *suppressVersion = [userDefaults stringForKey: SuppressFdaWarningSheetKey];
+
+  return [suppressVersion isEqualToString: self.appVersionString];
+}
+
+- (BOOL) shouldShowFdaWarningSheet {
+  // Always check, even when warning should be suppressed. This way, the log always contains the
+  // outcome of the FDA check, which can be helpful for trouble-shooting.
+  if ([self hasFdaPermissions]) {
+    return NO;
+  }
+
+  if ([self suppressFdaSheetEnabled]) {
+    return NO;
+  }
+
+  return YES;
+}
+
+- (void) showFdaWarningSheet {
+  NSAlert *alert = [[[NSAlert alloc] init] autorelease];
+
+  // First button is for the main/default action
+  [alert addButtonWithTitle: NSLocalizedString(@"Edit System Preferences", @"FDA warning sheet")];
+  [alert addButtonWithTitle: CANCEL_BUTTON_TITLE];
+  alert.messageText = NSLocalizedString
+    (@"GrandPerspective seems to lack Full Disk Access permissions",
+     @"FDA warning sheet");
+  [alert setInformativeText: NSLocalizedString
+    (@"This may limit the disk content it can see. To remedy this, you can grant the permissions via the System Preferences.",
+     @"FDA warning sheet")
+  ];
+
+  alert.showsSuppressionButton = YES;
+  alert.suppressionButton.target = self;
+  alert.suppressionButton.action = @selector(handleSuppressFdaWarningButton:);
+  alert.suppressionButton.title = NSLocalizedString(@"Do not show again", @"FDA warning sheet");
+
+  alert.suppressionButton.state = ([self suppressFdaSheetEnabled]
+                                   ? NSControlStateValueOn : NSControlStateValueOff);
+
+  [alert beginSheetModalForWindow: self.window completionHandler: ^(NSModalResponse returnCode) {
+    if (returnCode == NSAlertFirstButtonReturn) {
+      [self handleEditFdaPreferences];
+    }
+  }];
+}
+
+- (void) handleSuppressFdaWarningButton:(id)sender {
+  NSUserDefaults  *userDefaults = NSUserDefaults.standardUserDefaults;
+  if ([sender state] == NSControlStateValueOn) {
+    [userDefaults setObject: self.appVersionString forKey: SuppressFdaWarningSheetKey];
+  } else {
+    [userDefaults removeObjectForKey: SuppressFdaWarningSheetKey];
+  }
+}
+
+- (void) handleEditFdaPreferences {
+  NSURL *url = [NSURL URLWithString: fdaPreferencesUrl];
+  [NSWorkspace.sharedWorkspace openURL: url];
+}
+
 @end // @interface StartWindowControl (PrivateMethods)
