@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.6 
+/* GrandPerspective, Version 3.6.1 
  *   A utility for macOS that graphically shows disk usage. 
  * Copyright (C) 2005-2025, Erwin Bonsma 
  * 
@@ -22,8 +22,10 @@
 
 @protocol TaskExecutor;
 
+// Fired when a new task is scheduled.
+extern NSString  *TaskScheduledEvent;
 
-// Fired when a new task is started.
+// Fired when a new task started executing.
 extern NSString  *TaskStartedEvent;
 
 // Fired when a task completed, successfully or not.
