@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.6 
+/* GrandPerspective, Version 3.6.1 
  *   A utility for macOS that graphically shows disk usage. 
  * Copyright (C) 2005-2025, Erwin Bonsma 
  * 
@@ -22,8 +22,10 @@
 
 #import "TaskExecutor.h"
 
+// Fired when a new task is scheduled.
+NSString  *TaskScheduledEvent = @"taskScheduled";
 
-// Fired when a new task is started.
+// Fired when a new task is started executing.
 NSString  *TaskStartedEvent = @"taskStarted";
 
 // Fired when a task completed, successfully or not.
@@ -124,11 +126,14 @@ enum {
 - (void) asynchronouslyRunTaskWithInput:(id)input
                                callback:(id)callback
                                selector:(SEL)selector {
+  BOOL  taskWasScheduled = NO;
 
   [settingsLock lock];
   NSAssert(alive, @"Disturbing a dead task manager.");
   
   if (input != nextTaskInput) {
+    taskWasScheduled = nextTaskInput != nil;
+
     [nextTaskInput release];
     nextTaskInput = [input retain];
   }
@@ -151,6 +156,13 @@ enum {
   }
 
   [settingsLock unlock];
+
+  if (!taskWasScheduled) {
+    // Note: Only fire an event when there was not already a scheduled task. In the latter case,
+    // the old scheduled task is replaced by a new task, but the overall task execution status
+    // did not change. This simplifies task count related bookkeeping.
+    [NSNotificationCenter.defaultCenter postNotificationName: TaskScheduledEvent object: self];
+  }
 }
 
 @end
